@@ -231,8 +231,6 @@ class Logger(tasking.Tasker):
             self.desire = ABORT
             self.status = ABORTED
 
-
-
 class Log(registering.StoriedRegistry):
     """Log Class for logging to file
 
@@ -261,8 +259,6 @@ class Log(registering.StoriedRegistry):
            kind = text or binary
            rule = log rule conditions (NEVER, ONCE, ALWAYS, UPDATE, CHANGE)
            loggees = ordered dictionary of shares to be logged with tags
-
-
         """
         if 'preface' not in kw:
             kw['preface'] = 'Log'
@@ -293,7 +289,6 @@ class Log(registering.StoriedRegistry):
                 raise excepting.ResolveError("Bad loggee tag '_time'", self.name, loggee['_time'].name)
             self.loggees.update(loggees)
 
-
     def __call__(self, **kw):
         """run .action
 
@@ -301,7 +296,6 @@ class Log(registering.StoriedRegistry):
         self.action(**kw)
         console.profuse("     Log {0} at {1}\n".format(self.name, self.stamp))
 
-
     def createPath(self, prefix):
         """creates full path name of file
 
@@ -515,7 +509,6 @@ class Log(registering.StoriedRegistry):
 
         cf.close()
 
-
     def never(self):
         """log never
            This if for manual logging by frame action
@@ -608,100 +601,3 @@ class Log(registering.StoriedRegistry):
                     raise excepting.ResolveError("Loggee not in store", loggee, self.name)
                 self.loggees[tag] = share #replace link name with link
 
-def TestLog(rule = UPDATE):
-    """Module Common self test
-
-    """
-    storing.Store.Clear() #clear registry
-    Log.clear()
-
-
-    store = storing.Store(name = 'Test')
-    heading = store.create('pose.heading').create(value = 0.0)
-    position = store.create('pose.position').create(north = 10.0, east = 5.0)
-
-    log = Log(name = 'test', store = store, kind = 'console',
-              prefix = 'log', path = './logs/', rule = rule)
-    log.addLoggee(tag = 'heading', loggee = 'pose.heading')
-    log.addLoggee(tag = 'pos', loggee = 'pose.position')
-    log.resolve()
-    log.prepare()
-
-    print("logging log %s to file %s" % (log.name, log.fileName))
-    log() #log
-    for i in range(20):
-        store.advanceStamp(0.125)
-        if i == 5:
-            heading.value += 0.0
-            position.data.north += 0.0
-            position.data.east -= 0.0
-        elif i == 10:
-            pass
-        else:
-            heading.value = float(i)
-            position.data.north += 2.0
-            position.data.east -= 1.5
-
-        log() #log
-
-
-
-    log.close()
-
-
-
-
-def Test(rule = UPDATE):
-    """Module Common self test
-
-    """
-
-    storing.Store.Clear()
-    Logger.clear()
-    Log.clear()
-
-    store = storing.Store(name = 'Test')
-
-    heading = store.create('pose.heading').create(value = 0.0)
-    position = store.create('pose.position').create(north = 10.0, east = 5.0)
-
-    log = Log(name = 'test', store = store, kind = 'text',
-              prefix = 'log', path = './logs/', rule = rule)
-    log.addLoggee(tag = 'heading', loggee = 'pose.heading')
-    log.addLoggee(tag = 'pos', loggee = 'pose.position')
-    log.resolve()
-
-    logger = Logger(name = 'Test', store = store)
-    logger.addLog(log)
-
-    status = logger.runner.send(START) #also prepares logs
-    status = logger.runner.send(RUN)
-
-    for i in range(20):
-        store.advanceStamp(0.125)
-        if i == 5:
-            heading.value += 0.0
-            position.data.north += 0.0
-            position.data.east -= 0.0
-        elif i == 10:
-            pass
-        else:
-            heading.value = float(i)
-            position.data.north += 2.0
-            position.data.east -= 1.5
-
-        status = logger.runner.send(RUN)
-
-    status = logger.runner.send(STOP)
-
-    status = logger.runner.send(START)
-    store.advanceStamp(0.125)
-    heading.value += 5.0
-    status = logger.runner.send(RUN)
-    status = logger.runner.send(STOP)
-
-
-
-if __name__ == "__main__":
-    Test()
-
